@@ -8,10 +8,10 @@ fi
 if [ "x$1" = "x-f"  ]
 then
     autoscan
-    [ -f "configure.in" ] && cp "configure.in" "configure.in.old"
-    mv -f "configure.scan" "configure.in"
-    echo "## This is just AUTOSCAN draft of configure.in"
-    $EDITOR "configure.in"
+    [ -f "configure.ac" ] && cp "configure.ac" "configure.ac.old"
+    mv -f "configure.scan" "configure.ac"
+    echo "## This is just AUTOSCAN draft of configure.ac"
+    $EDITOR "configure.ac"
 fi
 
 ### použít jen když je třeba použít configure.h.in
